Documentation
¶
Overview ¶
Package v1 is a generated protocol buffer package.
It is generated from these files:
k8s.io/kubernetes/vendor/k8s.io/api/apps/v1/generated.proto
It has these top-level messages:
DaemonSet DaemonSetList DaemonSetSpec DaemonSetStatus DaemonSetUpdateStrategy RollingUpdateDaemonSet
Index ¶
- Constants
- Variables
- func RegisterDeepCopies(scheme *runtime.Scheme) errordeprecated
- func Resource(resource string) schema.GroupResource
- type DaemonSet
- func (in *DaemonSet) DeepCopy() *DaemonSet
- func (in *DaemonSet) DeepCopyInto(out *DaemonSet)
- func (in *DaemonSet) DeepCopyObject() runtime.Object
- func (*DaemonSet) Descriptor() ([]byte, []int)
- func (m *DaemonSet) Marshal() (dAtA []byte, err error)
- func (m *DaemonSet) MarshalTo(dAtA []byte) (int, error)
- func (*DaemonSet) ProtoMessage()
- func (m *DaemonSet) Reset()
- func (m *DaemonSet) Size() (n int)
- func (this *DaemonSet) String() string
- func (DaemonSet) SwaggerDoc() map[string]string
- func (m *DaemonSet) Unmarshal(dAtA []byte) error
- type DaemonSetList
- func (in *DaemonSetList) DeepCopy() *DaemonSetList
- func (in *DaemonSetList) DeepCopyInto(out *DaemonSetList)
- func (in *DaemonSetList) DeepCopyObject() runtime.Object
- func (*DaemonSetList) Descriptor() ([]byte, []int)
- func (m *DaemonSetList) Marshal() (dAtA []byte, err error)
- func (m *DaemonSetList) MarshalTo(dAtA []byte) (int, error)
- func (*DaemonSetList) ProtoMessage()
- func (m *DaemonSetList) Reset()
- func (m *DaemonSetList) Size() (n int)
- func (this *DaemonSetList) String() string
- func (DaemonSetList) SwaggerDoc() map[string]string
- func (m *DaemonSetList) Unmarshal(dAtA []byte) error
- type DaemonSetSpec
- func (in *DaemonSetSpec) DeepCopy() *DaemonSetSpec
- func (in *DaemonSetSpec) DeepCopyInto(out *DaemonSetSpec)
- func (*DaemonSetSpec) Descriptor() ([]byte, []int)
- func (m *DaemonSetSpec) Marshal() (dAtA []byte, err error)
- func (m *DaemonSetSpec) MarshalTo(dAtA []byte) (int, error)
- func (*DaemonSetSpec) ProtoMessage()
- func (m *DaemonSetSpec) Reset()
- func (m *DaemonSetSpec) Size() (n int)
- func (this *DaemonSetSpec) String() string
- func (DaemonSetSpec) SwaggerDoc() map[string]string
- func (m *DaemonSetSpec) Unmarshal(dAtA []byte) error
- type DaemonSetStatus
- func (in *DaemonSetStatus) DeepCopy() *DaemonSetStatus
- func (in *DaemonSetStatus) DeepCopyInto(out *DaemonSetStatus)
- func (*DaemonSetStatus) Descriptor() ([]byte, []int)
- func (m *DaemonSetStatus) Marshal() (dAtA []byte, err error)
- func (m *DaemonSetStatus) MarshalTo(dAtA []byte) (int, error)
- func (*DaemonSetStatus) ProtoMessage()
- func (m *DaemonSetStatus) Reset()
- func (m *DaemonSetStatus) Size() (n int)
- func (this *DaemonSetStatus) String() string
- func (DaemonSetStatus) SwaggerDoc() map[string]string
- func (m *DaemonSetStatus) Unmarshal(dAtA []byte) error
- type DaemonSetUpdateStrategy
- func (in *DaemonSetUpdateStrategy) DeepCopy() *DaemonSetUpdateStrategy
- func (in *DaemonSetUpdateStrategy) DeepCopyInto(out *DaemonSetUpdateStrategy)
- func (*DaemonSetUpdateStrategy) Descriptor() ([]byte, []int)
- func (m *DaemonSetUpdateStrategy) Marshal() (dAtA []byte, err error)
- func (m *DaemonSetUpdateStrategy) MarshalTo(dAtA []byte) (int, error)
- func (*DaemonSetUpdateStrategy) ProtoMessage()
- func (m *DaemonSetUpdateStrategy) Reset()
- func (m *DaemonSetUpdateStrategy) Size() (n int)
- func (this *DaemonSetUpdateStrategy) String() string
- func (DaemonSetUpdateStrategy) SwaggerDoc() map[string]string
- func (m *DaemonSetUpdateStrategy) Unmarshal(dAtA []byte) error
- type DaemonSetUpdateStrategyType
- type RollingUpdateDaemonSet
- func (in *RollingUpdateDaemonSet) DeepCopy() *RollingUpdateDaemonSet
- func (in *RollingUpdateDaemonSet) DeepCopyInto(out *RollingUpdateDaemonSet)
- func (*RollingUpdateDaemonSet) Descriptor() ([]byte, []int)
- func (m *RollingUpdateDaemonSet) Marshal() (dAtA []byte, err error)
- func (m *RollingUpdateDaemonSet) MarshalTo(dAtA []byte) (int, error)
- func (*RollingUpdateDaemonSet) ProtoMessage()
- func (m *RollingUpdateDaemonSet) Reset()
- func (m *RollingUpdateDaemonSet) Size() (n int)
- func (this *RollingUpdateDaemonSet) String() string
- func (RollingUpdateDaemonSet) SwaggerDoc() map[string]string
- func (m *RollingUpdateDaemonSet) Unmarshal(dAtA []byte) error
Constants ¶
const ( ControllerRevisionHashLabelKey = "controller-revision-hash" DeprecatedTemplateGeneration = "deprecated.daemonset.template.generation" )
const ( // DefaultDaemonSetUniqueLabelKey is the default label key that is added // to existing DaemonSet pods to distinguish between old and new // DaemonSet pods during DaemonSet template updates. DefaultDaemonSetUniqueLabelKey = ControllerRevisionHashLabelKey )
const GroupName = "apps"
GroupName is the group name use in this package
Variables ¶
var ( ErrInvalidLengthGenerated = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowGenerated = fmt.Errorf("proto: integer overflow") )
var ( // TODO: move SchemeBuilder with zz_generated.deepcopy.go to k8s.io/api. // localSchemeBuilder and AddToScheme will stay in k8s.io/kubernetes. SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = localSchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: "v1"}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func RegisterDeepCopies
deprecated
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type DaemonSet ¶
type DaemonSet struct {
metav1.TypeMeta `json:",inline"`
// Standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
// +optional
metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
// The desired behavior of this daemon set.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#spec-and-status
// +optional
Spec DaemonSetSpec `json:"spec,omitempty" protobuf:"bytes,2,opt,name=spec"`
// The current status of this daemon set. This data may be
// out of date by some window of time.
// Populated by the system.
// Read-only.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#spec-and-status
// +optional
Status DaemonSetStatus `json:"status,omitempty" protobuf:"bytes,3,opt,name=status"`
}
DaemonSet represents the configuration of a daemon set.
func (*DaemonSet) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DaemonSet.
func (*DaemonSet) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DaemonSet) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*DaemonSet) Descriptor ¶
func (*DaemonSet) ProtoMessage ¶
func (*DaemonSet) ProtoMessage()
func (DaemonSet) SwaggerDoc ¶
type DaemonSetList ¶
type DaemonSetList struct {
metav1.TypeMeta `json:",inline"`
// Standard list metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
// +optional
metav1.ListMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
// A list of daemon sets.
Items []DaemonSet `json:"items" protobuf:"bytes,2,rep,name=items"`
}
DaemonSetList is a collection of daemon sets.
func (*DaemonSetList) DeepCopy ¶
func (in *DaemonSetList) DeepCopy() *DaemonSetList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DaemonSetList.
func (*DaemonSetList) DeepCopyInto ¶
func (in *DaemonSetList) DeepCopyInto(out *DaemonSetList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DaemonSetList) DeepCopyObject ¶
func (in *DaemonSetList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*DaemonSetList) Descriptor ¶
func (*DaemonSetList) Descriptor() ([]byte, []int)
func (*DaemonSetList) Marshal ¶
func (m *DaemonSetList) Marshal() (dAtA []byte, err error)
func (*DaemonSetList) ProtoMessage ¶
func (*DaemonSetList) ProtoMessage()
func (*DaemonSetList) Reset ¶
func (m *DaemonSetList) Reset()
func (*DaemonSetList) Size ¶
func (m *DaemonSetList) Size() (n int)
func (*DaemonSetList) String ¶
func (this *DaemonSetList) String() string
func (DaemonSetList) SwaggerDoc ¶
func (DaemonSetList) SwaggerDoc() map[string]string
func (*DaemonSetList) Unmarshal ¶
func (m *DaemonSetList) Unmarshal(dAtA []byte) error
type DaemonSetSpec ¶
type DaemonSetSpec struct {
// A label query over pods that are managed by the daemon set.
// Must match in order to be controlled.
// If empty, defaulted to labels on Pod template.
// More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
// +optional
Selector *metav1.LabelSelector `json:"selector,omitempty" protobuf:"bytes,1,opt,name=selector"`
// An object that describes the pod that will be created.
// The DaemonSet will create exactly one copy of this pod on every node
// that matches the template's node selector (or on every node if no node
// selector is specified).
// More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
Template v1.PodTemplateSpec `json:"template" protobuf:"bytes,2,opt,name=template"`
// An update strategy to replace existing DaemonSet pods with new pods.
// +optional
UpdateStrategy DaemonSetUpdateStrategy `json:"updateStrategy,omitempty" protobuf:"bytes,3,opt,name=updateStrategy"`
// The minimum number of seconds for which a newly created DaemonSet pod should
// be ready without any of its container crashing, for it to be considered
// available. Defaults to 0 (pod will be considered available as soon as it
// is ready).
// +optional
MinReadySeconds int32 `json:"minReadySeconds,omitempty" protobuf:"varint,4,opt,name=minReadySeconds"`
// The number of old history to retain to allow rollback.
// This is a pointer to distinguish between explicit zero and not specified.
// Defaults to 10.
// +optional
RevisionHistoryLimit *int32 `json:"revisionHistoryLimit,omitempty" protobuf:"varint,6,opt,name=revisionHistoryLimit"`
}
DaemonSetSpec is the specification of a daemon set.
func (*DaemonSetSpec) DeepCopy ¶
func (in *DaemonSetSpec) DeepCopy() *DaemonSetSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DaemonSetSpec.
func (*DaemonSetSpec) DeepCopyInto ¶
func (in *DaemonSetSpec) DeepCopyInto(out *DaemonSetSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DaemonSetSpec) Descriptor ¶
func (*DaemonSetSpec) Descriptor() ([]byte, []int)
func (*DaemonSetSpec) Marshal ¶
func (m *DaemonSetSpec) Marshal() (dAtA []byte, err error)
func (*DaemonSetSpec) ProtoMessage ¶
func (*DaemonSetSpec) ProtoMessage()
func (*DaemonSetSpec) Reset ¶
func (m *DaemonSetSpec) Reset()
func (*DaemonSetSpec) Size ¶
func (m *DaemonSetSpec) Size() (n int)
func (*DaemonSetSpec) String ¶
func (this *DaemonSetSpec) String() string
func (DaemonSetSpec) SwaggerDoc ¶
func (DaemonSetSpec) SwaggerDoc() map[string]string
func (*DaemonSetSpec) Unmarshal ¶
func (m *DaemonSetSpec) Unmarshal(dAtA []byte) error
type DaemonSetStatus ¶
type DaemonSetStatus struct {
// The number of nodes that are running at least 1
// daemon pod and are supposed to run the daemon pod.
// More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
CurrentNumberScheduled int32 `json:"currentNumberScheduled" protobuf:"varint,1,opt,name=currentNumberScheduled"`
// The number of nodes that are running the daemon pod, but are
// not supposed to run the daemon pod.
// More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
NumberMisscheduled int32 `json:"numberMisscheduled" protobuf:"varint,2,opt,name=numberMisscheduled"`
// The total number of nodes that should be running the daemon
// pod (including nodes correctly running the daemon pod).
// More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
DesiredNumberScheduled int32 `json:"desiredNumberScheduled" protobuf:"varint,3,opt,name=desiredNumberScheduled"`
// The number of nodes that should be running the daemon pod and have one
// or more of the daemon pod running and ready.
NumberReady int32 `json:"numberReady" protobuf:"varint,4,opt,name=numberReady"`
// The most recent generation observed by the daemon set controller.
// +optional
ObservedGeneration int64 `json:"observedGeneration,omitempty" protobuf:"varint,5,opt,name=observedGeneration"`
// The total number of nodes that are running updated daemon pod
// +optional
UpdatedNumberScheduled int32 `json:"updatedNumberScheduled,omitempty" protobuf:"varint,6,opt,name=updatedNumberScheduled"`
// The number of nodes that should be running the
// daemon pod and have one or more of the daemon pod running and
// available (ready for at least spec.minReadySeconds)
// +optional
NumberAvailable int32 `json:"numberAvailable,omitempty" protobuf:"varint,7,opt,name=numberAvailable"`
// daemon pod and have none of the daemon pod running and available
// (ready for at least spec.minReadySeconds)
// +optional
NumberUnavailable int32 `json:"numberUnavailable,omitempty" protobuf:"varint,8,opt,name=numberUnavailable"`
// Count of hash collisions for the DaemonSet. The DaemonSet controller
// uses this field as a collision avoidance mechanism when it needs to
// create the name for the newest ControllerRevision.
// +optional
CollisionCount *int32 `json:"collisionCount,omitempty" protobuf:"varint,9,opt,name=collisionCount"`
}
DaemonSetStatus represents the current status of a daemon set.
func (*DaemonSetStatus) DeepCopy ¶
func (in *DaemonSetStatus) DeepCopy() *DaemonSetStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DaemonSetStatus.
func (*DaemonSetStatus) DeepCopyInto ¶
func (in *DaemonSetStatus) DeepCopyInto(out *DaemonSetStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DaemonSetStatus) Descriptor ¶
func (*DaemonSetStatus) Descriptor() ([]byte, []int)
func (*DaemonSetStatus) Marshal ¶
func (m *DaemonSetStatus) Marshal() (dAtA []byte, err error)
func (*DaemonSetStatus) ProtoMessage ¶
func (*DaemonSetStatus) ProtoMessage()
func (*DaemonSetStatus) Reset ¶
func (m *DaemonSetStatus) Reset()
func (*DaemonSetStatus) Size ¶
func (m *DaemonSetStatus) Size() (n int)
func (*DaemonSetStatus) String ¶
func (this *DaemonSetStatus) String() string
func (DaemonSetStatus) SwaggerDoc ¶
func (DaemonSetStatus) SwaggerDoc() map[string]string
func (*DaemonSetStatus) Unmarshal ¶
func (m *DaemonSetStatus) Unmarshal(dAtA []byte) error
type DaemonSetUpdateStrategy ¶
type DaemonSetUpdateStrategy struct {
// Type of daemon set update. Can be "RollingUpdate" or "OnDelete". Default is RollingUpdate.
// +optional
Type DaemonSetUpdateStrategyType `json:"type,omitempty" protobuf:"bytes,1,opt,name=type"`
// Rolling update config params. Present only if type = "RollingUpdate".
//---
// TODO: Update this to follow our convention for oneOf, whatever we decide it
// to be. Same as Deployment `strategy.rollingUpdate`.
// See https://github.com/kubernetes/kubernetes/issues/35345
// +optional
RollingUpdate *RollingUpdateDaemonSet `json:"rollingUpdate,omitempty" protobuf:"bytes,2,opt,name=rollingUpdate"`
}
DaemonSetUpdateStrategy is a struct used to control the update strategy for a DaemonSet.
func (*DaemonSetUpdateStrategy) DeepCopy ¶
func (in *DaemonSetUpdateStrategy) DeepCopy() *DaemonSetUpdateStrategy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DaemonSetUpdateStrategy.
func (*DaemonSetUpdateStrategy) DeepCopyInto ¶
func (in *DaemonSetUpdateStrategy) DeepCopyInto(out *DaemonSetUpdateStrategy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DaemonSetUpdateStrategy) Descriptor ¶
func (*DaemonSetUpdateStrategy) Descriptor() ([]byte, []int)
func (*DaemonSetUpdateStrategy) Marshal ¶
func (m *DaemonSetUpdateStrategy) Marshal() (dAtA []byte, err error)
func (*DaemonSetUpdateStrategy) MarshalTo ¶
func (m *DaemonSetUpdateStrategy) MarshalTo(dAtA []byte) (int, error)
func (*DaemonSetUpdateStrategy) ProtoMessage ¶
func (*DaemonSetUpdateStrategy) ProtoMessage()
func (*DaemonSetUpdateStrategy) Reset ¶
func (m *DaemonSetUpdateStrategy) Reset()
func (*DaemonSetUpdateStrategy) Size ¶
func (m *DaemonSetUpdateStrategy) Size() (n int)
func (*DaemonSetUpdateStrategy) String ¶
func (this *DaemonSetUpdateStrategy) String() string
func (DaemonSetUpdateStrategy) SwaggerDoc ¶
func (DaemonSetUpdateStrategy) SwaggerDoc() map[string]string
func (*DaemonSetUpdateStrategy) Unmarshal ¶
func (m *DaemonSetUpdateStrategy) Unmarshal(dAtA []byte) error
type DaemonSetUpdateStrategyType ¶
type DaemonSetUpdateStrategyType string
const ( // Replace the old daemons by new ones using rolling update i.e replace them on each node one after the other. RollingUpdateDaemonSetStrategyType DaemonSetUpdateStrategyType = "RollingUpdate" // Replace the old daemons only when it's killed OnDeleteDaemonSetStrategyType DaemonSetUpdateStrategyType = "OnDelete" )
type RollingUpdateDaemonSet ¶
type RollingUpdateDaemonSet struct {
// update. Value can be an absolute number (ex: 5) or a percentage of total
// number of DaemonSet pods at the start of the update (ex: 10%). Absolute
// number is calculated from percentage by rounding up.
// This cannot be 0.
// Default value is 1.
// Example: when this is set to 30%, at most 30% of the total number of nodes
// that should be running the daemon pod (i.e. status.desiredNumberScheduled)
// can have their pods stopped for an update at any given
// time. The update starts by stopping at most 30% of those DaemonSet pods
// and then brings up new DaemonSet pods in their place. Once the new pods
// are available, it then proceeds onto other DaemonSet pods, thus ensuring
// that at least 70% of original number of DaemonSet pods are available at
// all times during the update.
// +optional
MaxUnavailable *intstr.IntOrString `json:"maxUnavailable,omitempty" protobuf:"bytes,1,opt,name=maxUnavailable"`
}
Spec to control the desired behavior of daemon set rolling update.
func (*RollingUpdateDaemonSet) DeepCopy ¶
func (in *RollingUpdateDaemonSet) DeepCopy() *RollingUpdateDaemonSet
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RollingUpdateDaemonSet.
func (*RollingUpdateDaemonSet) DeepCopyInto ¶
func (in *RollingUpdateDaemonSet) DeepCopyInto(out *RollingUpdateDaemonSet)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RollingUpdateDaemonSet) Descriptor ¶
func (*RollingUpdateDaemonSet) Descriptor() ([]byte, []int)
func (*RollingUpdateDaemonSet) Marshal ¶
func (m *RollingUpdateDaemonSet) Marshal() (dAtA []byte, err error)
func (*RollingUpdateDaemonSet) MarshalTo ¶
func (m *RollingUpdateDaemonSet) MarshalTo(dAtA []byte) (int, error)
func (*RollingUpdateDaemonSet) ProtoMessage ¶
func (*RollingUpdateDaemonSet) ProtoMessage()
func (*RollingUpdateDaemonSet) Reset ¶
func (m *RollingUpdateDaemonSet) Reset()
func (*RollingUpdateDaemonSet) Size ¶
func (m *RollingUpdateDaemonSet) Size() (n int)
func (*RollingUpdateDaemonSet) String ¶
func (this *RollingUpdateDaemonSet) String() string
func (RollingUpdateDaemonSet) SwaggerDoc ¶
func (RollingUpdateDaemonSet) SwaggerDoc() map[string]string
func (*RollingUpdateDaemonSet) Unmarshal ¶
func (m *RollingUpdateDaemonSet) Unmarshal(dAtA []byte) error